//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/InputOutput/ReadWriteINT.h
//! @brief     Defines ReadWriteINT
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_DEVICE_INPUTOUTPUT_READWRITEINT_H
#define BORNAGAIN_DEVICE_INPUTOUTPUT_READWRITEINT_H

#include <istream>

template <class T>
class Powerfield;

//! Class for reading and writing BornAgain native IntensityData from ASCII file.

class ReadWriteINT {
public:
    Powerfield<double>* readPowerfield(std::istream& input_stream);
    void writePowerfield(const Powerfield<double>& data, std::ostream& output_stream);

private:
    static void writePowerfieldDoubles(const Powerfield<double>& data, std::ostream& output_stream,
                                       size_t n_columns);
    static double ignoreDenormalized(double value);
};

#endif // BORNAGAIN_DEVICE_INPUTOUTPUT_READWRITEINT_H
#endif // USER_API
