//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/ItemWithMaterial.cpp
//! @brief     Implements class ItemWithMaterial
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Sample/ItemWithMaterial.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/Sample/MaterialItem.h"
#include "GUI/Model/Sample/MaterialItems.h"

void ItemWithMaterial::setMaterial(const MaterialItem* materialItem)
{
    m_materialIdentifier = materialItem->identifier();
}

void ItemWithMaterial::setMaterial(const QString& materialIdentifier)
{
    m_materialIdentifier = materialIdentifier;
}


ItemWithMaterial::ItemWithMaterial(const MaterialItems* materials)
    : m_materialItems(materials)
{
    ASSERT(m_materialItems);
}

void ItemWithMaterial::setMaterialUndefined()
{
    m_materialIdentifier.clear();
}

QColor ItemWithMaterial::materialColor() const
{
    ASSERT(materialItem());
    return materialItem()->color();
}

QString ItemWithMaterial::materialName() const
{
    ASSERT(materialItem());
    return materialItem()->matItemName();
}

QString ItemWithMaterial::materialIdentifier() const
{
    return m_materialIdentifier;
}

MaterialItem* ItemWithMaterial::materialItem() const
{
    if (materialIdentifier().isEmpty())
        return nullptr;

    return m_materialItems->materialFromIdentifier(materialIdentifier());
}
