//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Support/Type/GroupInfo.cpp
//! @brief     Defines class GroupInfo
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Support/Type/GroupInfo.h"
#include "Base/Util/Assert.h"

GroupInfo::GroupInfo(bool is_sorted)
    : is_sorted(is_sorted)
{
}

void GroupInfo::add(const QString& itemType, const QString& itemLabel)
{
    ASSERT(!containsType(itemType));
    m_info.push_back({itemType, itemLabel});

    if (is_sorted)
        std::sort(m_info.begin(), m_info.end(),
                  [](TypeAndLabel a, TypeAndLabel b) { return a.m_itemType < b.m_itemType; });
}

QString GroupInfo::defaultType() const
{
    if (m_defaultItemType.isEmpty() && !m_info.empty())
        return m_info[0].m_itemType;
    return m_defaultItemType;
}

void GroupInfo::setDefaultType(const QString& modelType)
{
    ASSERT(containsType(modelType));
    m_defaultItemType = modelType;
}

QStringList GroupInfo::itemTypes() const
{
    QStringList result;
    for (const auto& pair : m_info)
        result.append(pair.m_itemType);
    return result;
}

QStringList GroupInfo::itemLabels() const
{
    QStringList result;
    for (const auto& pair : m_info)
        result.append(pair.m_itemLabel);
    return result;
}

bool GroupInfo::containsType(const QString& itemType) const
{
    for (const auto& pair : m_info)
        if (itemType == pair.m_itemType)
            return true;
    return false;
}
