//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/DetectorAlignmentEditor.h
//! @brief     A widget for editing the alignment of a detector
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_INSTRUMENT_DETECTORALIGNMENTEDITOR_H
#define BORNAGAIN_GUI_VIEW_INSTRUMENT_DETECTORALIGNMENTEDITOR_H

#include <QWidget>

class DetectorAlignmentForm;
class RectangularDetectorItem;
class QFormLayout;
class DoubleSpinBox;
class DoubleDescriptor;
class VectorDescriptor;

/// Widget for selecting the alignment of a detector (combo box) and input of the corresponding
/// values

class DetectorAlignmentEditor : public QWidget {
    Q_OBJECT
public:
    DetectorAlignmentEditor(QWidget* parent, RectangularDetectorItem* item);

signals:
    void dataChanged();

private:
    void createAligmentWidgets();
    DoubleSpinBox* createSpinBox(QFormLayout* parentFormLayout, const DoubleDescriptor& d);
    DoubleSpinBox* createSpinBox(QWidget* parent, const DoubleDescriptor& d);
    void addVector(QFormLayout* parentLayout, const VectorDescriptor& d);

private:
    RectangularDetectorItem* m_item;
    QFormLayout* m_formLayout;
};

#endif // BORNAGAIN_GUI_VIEW_INSTRUMENT_DETECTORALIGNMENTEDITOR_H
