//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Aggregate/InterferenceTwin.h
//! @brief     Defines class InterferenceTwin.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCETWIN_H
#define BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCETWIN_H

#include "Sample/Aggregate/IInterference.h"

//! Interference function for two particles at a mean distance and given standard deviation
//! from each other in a given direction.
//! TODO: RENAME (has nothing to do with crystallographic twin)
//! @ingroup interference

class InterferenceTwin : public IInterference {
public:
    InterferenceTwin(const R3& direction, double mean_distance, double std_dev);

    InterferenceTwin* clone() const override;
    std::string className() const final { return "InterferenceTwin"; }
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"MeanDistance", "nm", "mean distance", 0, +INF, 0},
                {"StdDeviation", "nm", "standard deviation of distance", 0, +INF, 0}};
    }

    R3 direction() const;
    double meanDistance() const;
    double stdDev() const;

private:
    double iff_without_dw(R3 q) const override;

    R3 m_direction;
    double m_distance;
    double m_std_dev;
};

#endif // BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCETWIN_H
