//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Particle/Particle.cpp
//! @brief     Implements class Particle.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sample/Particle/Particle.h"
#include "Base/Util/Assert.h"
#include "Base/Vector/RotMatrix.h"
#include "Sample/Scattering/Rotations.h"

Particle::Particle(Material material, const IFormFactor& formfactor)
    : m_material(std::move(material))
    , m_formfactor(formfactor.clone())
{
}

Particle::Particle(Material material, const IFormFactor& formfactor, const IRotation& rotation)
    : Particle(material, formfactor)
{
    setRotation(rotation);
}

Particle::~Particle() = default;

Particle* Particle::clone() const
{
    ASSERT(m_formfactor);
    auto* p_result = new Particle(m_material, *m_formfactor);
    p_result->setAbundance(m_abundance);
    if (m_rotation)
        p_result->setRotation(*m_rotation);
    p_result->setParticlePosition(m_position);

    return p_result;
}

std::vector<const INode*> Particle::nodeChildren() const
{
    return std::vector<const INode*>() << IParticle::nodeChildren() << m_formfactor;
}
