//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sim/Scan/ISpecularScan.cpp
//! @brief     Implements interface ISpecularScan.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "Sim/Scan/ISpecularScan.h"
#include "Base/Element/PolMatrices.h"
#include "Device/Pol/PolFilter.h"

ISpecularScan::~ISpecularScan() = default;

void ISpecularScan::setPolarization(R3 bloch_vector)
{
    m_beamPolarization.reset(new R3(bloch_vector));
}

void ISpecularScan::setAnalyzer(R3 direction, double efficiency, double total_transmission)
{
    m_polAnalyzer.reset(new PolFilter(direction, efficiency, total_transmission));
}

bool ISpecularScan::polarized() const
{
    return m_beamPolarization || m_polAnalyzer;
}

PolMatrices ISpecularScan::polMatrices() const
{
    PolMatrices result;
    if (m_beamPolarization)
        result.setPolarizerMatrix(SpinMatrix::FromBlochVector(*m_beamPolarization));
    if (m_polAnalyzer)
        result.setAnalyzerMatrix(m_polAnalyzer->matrix());
    return result;
}
