//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Tests/Unit/GUI/Utils.cpp
//! @brief     Implements auxiliary test functions in a namespace.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2015
//! @authors   Scientific Computing Group at MLZ Garching
//
//  ************************************************************************************************

#include "Tests/Unit/GUI/Utils.h"
#include "Device/Data/DataUtils.h"
#include "Device/Histo/IOFactory.h"
#include "GUI/Model/Data/RealDataItem.h"
#include "GUI/Model/Model/SessionModel.h"
#include "GUI/Support/IO/ProjectUtils.h"
#include "GUI/Util/Error.h"
#include <QDir>

namespace {

const int nxsize = 5;
const int nysize = 10;

} // namespace

void UTest::GUI::create_dir(const QString& dir_name)
{
    if (QFile::exists(dir_name))
        QDir(dir_name).removeRecursively();

    if (!QDir(".").mkdir(dir_name))
        throw Error("UTest::GUI::create_dir() -> Error. Can't create '" + dir_name
                    + "' in parent directory '.'.");
}

std::unique_ptr<Powerfield<double>> UTest::GUI::createData(double value, DIM n_dim)
{
    std::vector<IAxis*> axes;
    axes.emplace_back(new FixedBinAxis("x", nxsize, -1.0, 1.0));
    if (n_dim == DIM::D2)
        axes.emplace_back(new FixedBinAxis("y", nysize, 0.0, 2.0));

    std::unique_ptr<Powerfield<double>> result(new Powerfield<double>(axes));
    result->setAllTo(value);
    return result;
}

RealDataItem* UTest::GUI::createRealData(const QString& name, SessionModel& model, double value,
                                         DIM n_dim)
{
    auto* result = model.insertItem<RealDataItem>();
    result->setPowerfield(createData(value, n_dim).release());
    result->setDataName(name);
    return result;
}

bool UTest::GUI::isTheSame(const Powerfield<double>& data1, const Powerfield<double>& data2)
{
    double diff = DataUtils::Data::relativeDataDifference(data1, data2);
    return diff < 1e-10;
}

bool UTest::GUI::isTheSame(const QString& fileName, const Powerfield<double>& data)
{
    std::unique_ptr<Powerfield<double>> dataOnDisk(
        IOFactory::readPowerfield(fileName.toStdString()));
    return isTheSame(*dataOnDisk, data);
}
